(*
  TPLib: Tropical Polyhedra Library

  TPLib allows to compute a description by means of vertices and rays 
  of tropical polyhedra defined by means of inequalities, and conversely.

  It also provides a numerical abstract domain based on tropical polyhedra, 
  in order to infer min-/max- invariants over programs.

  Copyright (C) 2009-2012 Xavier ALLAMIGEON (xavier.allamigeon at inria.fr)
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*)

module Make :
  functor (S : Semiring.T) ->
    functor (V : Vector.T with type scalar_t = S.t) ->
      sig
        type t = { apex : V.t; sectors : int list; }
        exception Unbounded_apex
        val of_inequality : ?gen:V.t list -> V.t -> t
        val to_inequality : t -> V.t
        val print : ?neg:bool -> Format.formatter -> t -> unit
        val equal : t -> t -> bool
        val hash : t -> int
      end
